@@ -29,8 +29,11 @@ def calc_skipchan(lowband_obj, upband_obj):
     Calculate the number of frequency channels to
     skip from top of lower and bottom of upper
     frequency bands
-    :param lowband_obj: Your object for the lower frequency band
-    :param upband_obj: Your object for the upper frequency band
+
+    Args:
+        lowband_obj: Your object for the lower frequency band
+        upband_obj: Your object for the upper frequency band
+
     """
     assert lowband_obj.bw / lowband_obj.nchans == upband_obj.bw / upband_obj.nchans
     logger.debug(
@@ -65,25 +68,33 @@ def read_and_combine_subint(lowband_obj, upband_obj, fsub, upchanskip, lowchansk
     scales and offsets, rescale the scales and offsets
     according to mean ratio of the overlapping channels
     from the two bands, and returns combined data
-    :param lowband_obj: Your object for the lower frequency band
-    :param upband_obj: Your object for the upper frequency band
-    :fsub: subint to read
-    :upchanskip: Lower channels to skip from the upperband
-    :lowchanskip: Upper channels to skip from the lower band
-    :return data: Combined data for the input subint
+
+    Args:
+        lowband_obj: Your object for the lower frequency band
+        upband_obj: Your object for the upper frequency band
+        fsub: subint to read
+        upchanskip: Lower channels to skip from the upperband
+        lowchanskip: Upper channels to skip from the lower band
+
+    Returns:
+        data: Combined data for the input subint
+
     """
     lowsub_data = lowband_obj.read_subint(
         fsub, apply_weights=False, apply_scales=False, apply_offsets=False
-    )
+    )[:, 0, :]
     lowsub_scales = lowband_obj.get_scales(fsub)[: lowband_obj.nchan]
     lowsub_offsets = lowband_obj.get_offsets(fsub)[: lowband_obj.nchan]
 
     upsub_data = upband_obj.read_subint(
         fsub, apply_weights=False, apply_scales=False, apply_offsets=False
-    )
+    )[:, 0, :]
     upsub_scales = upband_obj.get_scales(fsub)[: upband_obj.nchan]
     upsub_offsets = upband_obj.get_offsets(fsub)[: upband_obj.nchan]
 
+    logger.debug(f"Shape of lowband data is {lowsub_data.shape}.")
+    logger.debug(f"Shape of upband data is {upsub_data.shape}.")
+
     logger.debug(
         f"Read data, scales and offset of subint {fsub} from upper and lower band."
     )
@@ -144,11 +155,16 @@ def make_sigproc_obj(filfile, lowband_obj, nchan, fch1, foff):
     """
     Use Your class object of the lower band to make Sigproc
     class object with the relevant parameters
-    :param filfile: Name of the Filterbank file
-    :param lowband_obj: Your object for the lower frequency band
-    :param nchan: Number of channels in the combined data
-    :param fch1: Frequency of the first channel
-    :return fil_obj: Sigproc class object
+
+    Args:
+        filfile: Name of the Filterbank file
+        lowband_obj: Your object for the lower frequency band
+        nchan: Number of channels in the combined data
+        fch1: Frequency of the first channel
+
+    Returns:
+        fil_obj: Sigproc class object
+
     """
     logger.debug(f"Generating Sigproc object")
     fil_obj = SigprocFile()
@@ -202,12 +218,15 @@ def write_fil(data, lowband_obj, upband_obj, filename=None, outdir=None):
     """
     Write Filterbank file given the upper and lower band Your
     objects and combined data
-    :param lowband_obj: Your object for the lower frequency band
-    :param upband_obj: Your object for the upper frequency band
-    :param upband_obj: Your object for the upper frequency band
-    :param data: Combined data from two bands
-    :param filename: Output name of the Filterbank file
-    :param outdir: Output directory for the Filterbank file
+
+    Args:
+        lowband_obj: Your object for the lower frequency band
+        upband_obj: Your object for the upper frequency band
+        upband_obj: Your object for the upper frequency band
+        data: Combined data from two bands
+        filename: Output name of the Filterbank file
+        outdir: Output directory for the Filterbank file
+
     """
 
     original_dir, orig_lowband_basename = os.path.split(
@@ -252,12 +271,15 @@ def combine(f1, f2, nstart=0, nsamp=100, outdir=None, filfile=None):
     """
     combines data from two subbands from Mock spectrometer
     and writes out a Filterbank file.
-    :param f1: List of files from one subband
-    :param f2: List of files from other subband
-    :param nstart: Starting sample
-    :param nsamp: number of samples to read
-    :param outdir: Output directory for Filterbank file
-    :param filfile: Name of the Filterbank file to write to
+
+    Args:
+        f1: List of files from one subband
+        f2: List of files from other subband
+        nstart: Starting sample
+        nsamp: number of samples to read
+        outdir: Output directory for Filterbank file
+        filfile: Name of the Filterbank file to write to
+
     """
     y1 = Your(f1)
     y2 = Your(f2)
@@ -272,6 +294,10 @@ def combine(f1, f2, nstart=0, nsamp=100, outdir=None, filfile=None):
 
     low_header = vars(lowband_obj.your_header)
     up_header = vars(upband_obj.your_header)
+
+    logger.debug(f"Header of lowband file is: {low_header}")
+    logger.debug(f"Header of upband file is: {up_header}")
+
     for key in low_header.keys():
         if (
             key == "filelist"
@@ -290,6 +316,14 @@ def combine(f1, f2, nstart=0, nsamp=100, outdir=None, filfile=None):
                 )
             else:
                 continue
+        elif key == "basename":
+            up_base = ".".join(up_header["basename"].split(".")[:-2])
+            low_base = ".".join(low_header["basename"].split(".")[:-2])
+            if up_base != low_base:
+                logger.warning(
+                    f"Basenames ({up_base, low_base}) are unequal! Please check the two files carefully."
+                )
+            continue
 
         if low_header[key] != up_header[key]:
             raise ValueError(f"Values of {key} are different in the two bands")
@@ -300,7 +334,7 @@ def combine(f1, f2, nstart=0, nsamp=100, outdir=None, filfile=None):
     upchanskip, lowchanskip = calc_skipchan(lowband_obj, upband_obj)
 
     if nsamp == -1:
-        nsamp = lowband_obj.nspectra
+        nsamp = lowband_obj.your_header.nspectra
 
     # Calculate starting subint and ending subint
     startsub = int(nstart / lowband_obj.nsamp_per_subint)
@@ -363,7 +397,7 @@ def combine(f1, f2, nstart=0, nsamp=100, outdir=None, filfile=None):
             upband_obj.fileid += 1
 
             if lowband_obj.fileid == len(lowband_obj.filelist):
-                logger.warn(f"Not enough subints, returning data till last subint")
+                logger.warning(f"Not enough subints, returning data till last subint")
                 logger.debug(f"Setting file ID to that of last file")
                 lowband_obj.fileid -= 1
                 upband_obj.fileid -= 1
@@ -399,7 +433,7 @@ def combine(f1, f2, nstart=0, nsamp=100, outdir=None, filfile=None):
                 lowband_obj, upband_obj, fsub, upchanskip, lowchanskip
             )
         except KeyError:
-            logger.warn(f"Encountered KeyError, maybe mmap'd object was delected")
+            logger.warning(f"Encountered KeyError, maybe mmap'd object was delected")
             logger.debug(
                 f"Trying to open files {lowband_obj.filename} and {upband_obj.filename}"
             )
@@ -601,6 +635,10 @@ if __name__ == "__main__":
                 handlers=[RichHandler(rich_tracebacks=True)],
             )
 
+    logging.info("Input Arguments:-")
+    for arg, value in sorted(vars(values).items()):
+        logging.info("%s: %r", arg, value)
+
     if values.all_files:
         all_files(
             values.all_files,
