@@ -124,9 +124,9 @@ class PsrfitsFile(object):
 
         # Unifying properties with pysigproc
         self.npol = self.npoln
-        self.bw = self.header["OBSBW"]
+        self.bw = self.specinfo.BW
         self.cfreq = self.header["OBSFREQ"]
-        self.fch1 = self.cfreq - self.bw / 2.0  # Verify
+        self.fch1 = self.freqs[0]  # self.cfreq - self.bw / 2.0  # Verify
         self.foff = self.bw / self.nchan
         self.nchans = self.nchan
         self.tstart = self.specinfo.start_MJD[0]
@@ -252,6 +252,7 @@ class PsrfitsFile(object):
                 data = np.zeros((self.nsamp_per_subint, self.nchan), dtype=np.float32)
                 data += sdata[:, 0, :].squeeze()
                 data += sdata[:, 1, :].squeeze()
+                data *= 0.5
             elif len(shp) == 3 and shp[1] == self.npoln and self.poln_order == "IQUV":
                 logger.warning("Polarization is IQUV")
                 data = np.zeros((self.nsamp_per_subint, self.nchan), dtype=np.float32)
@@ -277,6 +278,7 @@ class PsrfitsFile(object):
                 data = np.zeros((self.nsamp_per_subint, self.nchan), dtype=np.float32)
                 data += sdata[:, 0, :].squeeze()
                 data += sdata[:, 1, :].squeeze()
+                data *= 0.5
             elif len(shp) == 4 and shp[-1] == 2 and self.poln_order == "IQUV":
                 logger.warning(
                     "Data is packed as two uint8 arrays. Concatenating them to get uint16."
@@ -764,12 +766,12 @@ class SpectraInfo:
         self.bytes_per_subint = self.bytes_per_spectra * self.spectra_per_subint
 
         # Flip the band?
-        if self.hi_freq < self.lo_freq:
-            tmp = self.hi_freq
-            self.hi_freq = self.lo_freq
-            self.lo_freq = tmp
-            self.df *= -1.0
-            self.need_flipband = True
+        # if self.hi_freq < self.lo_freq:
+        #    tmp = self.hi_freq
+        #    self.hi_freq = self.lo_freq
+        #    self.lo_freq = tmp
+        #    self.df *= -1.0
+        #    self.need_flipband = True
         # Compute the bandwidth
         self.BW = self.num_channels * self.df
         self.mjd = int(self.start_MJD[0])
