@@ -28,6 +28,7 @@ class Writer:
         c_min (int): Starting channel index (default: 0)
         c_max (int): End channel index (default: total number of frequencies)
         npoln (int): Number of output polarisations (default: 1)
+        highest_frequency_first (bool): The output should have highest frequency first (default: False)
         outdir (str): Output directory for file
         outname (str): Name of the file to write to (without the file extension)
         progress (bool): Set to it to false to disable progress bars
@@ -51,6 +52,7 @@ class Writer:
         c_min=None,
         c_max=None,
         npoln=1,
+        highest_frequency_first=False,
         outdir=None,
         outname=None,
         flag_rfi=False,
@@ -75,6 +77,7 @@ class Writer:
         self.c_min = c_min
         self.c_max = c_max
         self.npoln = npoln
+        self.highest_frequency_first = highest_frequency_first
 
         self.time_decimation_factor = time_decimation_factor
         self.frequency_decimation_factor = frequency_decimation_factor
@@ -110,7 +113,16 @@ class Writer:
             p = np.sort(primes(self.nsamp))[::-1]
             if len(p) > 1:
                 cumprods = np.cumprod(p)
-                self.gulp = int(cumprods[len(cumprods) // 2])
+                sizes_mb = (
+                    cumprods
+                    * self.your_object.your_header.nchans
+                    * self.your_object.your_header.nbits
+                    / 8
+                    / 1024
+                    / 1024
+                )
+                index_closest_to_1gb = np.argmin(np.abs(sizes_mb - 1024))
+                self.gulp = int(cumprods[index_closest_to_1gb])
             else:
                 self.gulp = self.nsamp
 
@@ -154,7 +166,10 @@ class Writer:
 
     @property
     def chan_freqs(self):
-        return self.your_object.chan_freqs[self.chan_min : self.chan_max]
+        chan_freqs = self.your_object.chan_freqs[self.chan_min : self.chan_max]
+        if self.highest_frequency_first and chan_freqs[0] < chan_freqs[-1]:
+            chan_freqs = chan_freqs[::-1]
+        return chan_freqs
 
     @property
     def nchans(self):
@@ -167,6 +182,13 @@ class Writer:
             + self.nstart * self.your_object.your_header.tsamp / (60 * 60 * 24)
         )
 
+    @property
+    def foff(self):
+        if self.highest_frequency_first and self.your_object.your_header.foff > 0:
+            return -self.your_object.your_header.foff
+        else:
+            return self.your_object.your_header.foff
+
     @property
     def poln_order(self):
         if self.npoln == 1:
@@ -243,6 +265,8 @@ class Writer:
         data = data.astype(self.your_object.your_header.dtype)
 
         # shape of data is (nt, npoln, nf)
+        if self.highest_frequency_first and self.your_object.your_header.foff > 0:
+            data = data[:, :, ::-1]
         self.data = data
 
     def to_fil(self, data=None):
@@ -261,6 +285,12 @@ class Writer:
             )
             self.npoln = 1
 
+        if self.your_object.your_header.nbits == 16:
+            logger.warning(
+                f"Data are being written with dtype uint16, if the original data were int16 appropriate scaling may "
+                f"be needed. "
+            )
+
         with Progress() as progress:
             if not self.progress:
                 task = progress.add_task(
@@ -289,8 +319,6 @@ class Writer:
                     while samples_left > 0:
                         self.get_data_to_write(start_sample, self.gulp)
                         self.data = self.data.squeeze()
-                        start_sample += self.gulp
-                        samples_left -= self.gulp
                         # goto the end of the file and dump
                         f.seek(0, os.SEEK_END)
                         f.write(self.data.ravel())
@@ -298,6 +326,8 @@ class Writer:
                         logger.debug(
                             f"Wrote from spectra {start_sample}-{start_sample + self.gulp} to the filterbank"
                         )
+                        start_sample += self.gulp
+                        samples_left -= self.gulp
             else:
                 if data.dtype == self.your_object.your_header.dtype:
                     logger.debug(f"write data of shape {data.shape} to {self.outname}")
@@ -423,7 +453,7 @@ class Writer:
 
         """
         header = dict()
-        header["BW"] = str(self.nchans * self.your_object.your_header.foff)
+        header["BW"] = str(self.nchans * self.foff)
         header["FREQ"] = str((self.chan_freqs[0] + self.chan_freqs[-1]) / 2)
         tstart = Time(self.tstart, format="mjd")
         header["MJD_START"] = str(self.tstart)
